@@ -2,7 +2,7 @@ from typing import Sequence
 from langchain.tools import BaseTool
 from langchain_core.language_models.base import LanguageModelLike
 from langchain_core.runnables import RunnableBinding
-from .agent_types import create_openai_func_call_agent_executor, create_react_agent_executor
+from .agent_types import create_openai_func_call_agent_executor
 
 
 class Runnable(RunnableBinding):
@@ -18,18 +18,18 @@ class Runnable(RunnableBinding):
         tools: Sequence[BaseTool],
         llm: LanguageModelLike,
         assistant_message: str,
+        tool_compatibility_mode: bool
     ) -> None:
-        
-        if agent_execution_mode == "FuncCall":
-            agent_executor_object = create_openai_func_call_agent_executor
-        else:
-            agent_executor_object = create_react_agent_executor
-        agent_executor = agent_executor_object(tools, llm, assistant_message)
+
+        agent_executor = create_openai_func_call_agent_executor(
+            tools, llm, assistant_message, tool_compatibility_mode
+        )
         agent_executor = agent_executor.with_config({"recursion_limit": 50})
         super().__init__(
             tools=tools,
             llm=llm,
             agent_execution_mode=agent_execution_mode,
             assistant_message=assistant_message,
-            bound=agent_executor, return_intermediate_steps=True
-        )
\ No newline at end of file
+            bound=agent_executor,
+            return_intermediate_steps=True,
+        )
